"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.grafserv = exports.ExpressGrafserv = void 0;
const utils_js_1 = require("../../../utils.js");
const index_js_1 = require("../../node/index.js");
class ExpressGrafserv extends index_js_1.NodeGrafservBase {
    getDigest(dynamicOptions, req, res) {
        return {
            httpVersionMajor: req.httpVersionMajor,
            httpVersionMinor: req.httpVersionMinor,
            isSecure: req.secure,
            method: req.method,
            path: req.path,
            headers: (0, utils_js_1.processHeaders)(req.headers),
            getQueryParams() {
                return req.query;
            },
            getBody() {
                if (req.body != null) {
                    return (0, utils_js_1.getBodyFromFrameworkBody)(req.body);
                }
                else {
                    return (0, utils_js_1.getBodyFromRequest)(req, dynamicOptions.maxRequestLength);
                }
            },
            requestContext: {
                node: {
                    req,
                    res,
                },
                expressv4: {
                    req,
                    res,
                },
            },
        };
    }
    async addTo(app, server) {
        app.use(this._createHandler());
        if (this.resolvedPreset.grafserv?.websockets) {
            if (server) {
                // If user explicitly passes server, bind to it:
                (0, index_js_1.attachWebsocketsToServer)(this, server);
            }
            else {
                // If not, hope they're calling `app.listen()` and intercept that call.
                const oldListen = app.listen;
                app.listen = (...args) => {
                    const server = oldListen.apply(app, args);
                    (0, index_js_1.attachWebsocketsToServer)(this, server);
                    return server;
                };
            }
        }
    }
}
exports.ExpressGrafserv = ExpressGrafserv;
function grafserv(config) {
    return new ExpressGrafserv(config);
}
exports.grafserv = grafserv;
//# sourceMappingURL=index.js.map